summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccount.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/kopeteaccount.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteaccount.h')
-rw-r--r--kopete/libkopete/kopeteaccount.h59
1 files changed, 30 insertions, 29 deletions
diff --git a/kopete/libkopete/kopeteaccount.h b/kopete/libkopete/kopeteaccount.h
index 8782673c..44f12eb1 100644
--- a/kopete/libkopete/kopeteaccount.h
+++ b/kopete/libkopete/kopeteaccount.h
@@ -63,19 +63,20 @@ class BlackLister;
*
* @author Olivier Goffart <ogoffart@tiscalinet.be>
*/
-class KOPETE_EXPORT Account : public QObject
+class KOPETE_EXPORT Account : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
Q_ENUMS( AddMode )
- Q_PROPERTY( TQString accountId READ accountId )
- Q_PROPERTY( bool excludeConnect READ excludeConnect WRITE setExcludeConnect )
- Q_PROPERTY( TQColor color READ color WRITE setColor )
- Q_PROPERTY( TQPixmap accountIcon READ accountIcon )
- Q_PROPERTY( bool isConnected READ isConnected )
- Q_PROPERTY( bool isAway READ isAway )
- Q_PROPERTY( bool suppressStatusNotification READ suppressStatusNotification )
- Q_PROPERTY( uint priority READ priority WRITE setPriority )
+ TQ_PROPERTY( TQString accountId READ accountId )
+ TQ_PROPERTY( bool excludeConnect READ excludeConnect WRITE setExcludeConnect )
+ TQ_PROPERTY( TQColor color READ color WRITE setColor )
+ TQ_PROPERTY( TQPixmap accountIcon READ accountIcon )
+ TQ_PROPERTY( bool isConnected READ isConnected )
+ TQ_PROPERTY( bool isAway READ isAway )
+ TQ_PROPERTY( bool suppressStatusNotification READ suppressStatusNotification )
+ TQ_PROPERTY( uint priority READ priority WRITE setPriority )
public:
/**
@@ -97,12 +98,12 @@ public:
};
/**
* @param parent the protocol for this account. The account is a child object of the
* protocol, so it will be automatically deleted when the protocol is.
* @param accountID the unique ID of this account.
* @param name the name of this TQObject.
*/
- Account(Protocol *parent, const TQString &accountID, const char *name=0L);
+ Account(Protocol *tqparent, const TQString &accountID, const char *name=0L);
~Account();
/**
@@ -181,7 +182,7 @@ public:
/**
* \brief change the account icon.
* by default the icon of an account is the protocol one, but it may be overide it.
- * Set TQString::null to go back to the default (the protocol icon)
+ * Set TQString() to go back to the default (the protocol icon)
*
* this call will emit colorChanged()
*/
@@ -264,28 +265,28 @@ public:
* If @p mode is @c DontChangeKABC, no additional action is carried out.
*
* @param contactId the @ref Contact::contactId of the contact to create
- * @param displayName the displayname (alias) of the new metacontact. Leave as TQString::null if
+ * @param displayName the displayname (alias) of the new metacontact. Leave as TQString() if
* no alias is known, then by default, the nick will be taken as alias and tracked if changed.
* @param group the group to add the created metacontact to, or 0 for the top-level group.
* @param mode the mode used to add the contact. Use DontChangeKABC when deserializing.
* @return the new created metacontact or 0L if the operation failed
*/
- MetaContact* addContact( const TQString &contactId, const TQString &displayName = TQString::null, Group *group = 0, AddMode mode = DontChangeKABC ) ;
+ MetaContact* addContact( const TQString &contactId, const TQString &displayName = TQString(), Group *group = 0, AddMode mode = DontChangeKABC ) ;
/**
* @brief Create a new contact, adding it to an existing metacontact
*
* If a contact for this account with ID @p contactId is not already on the contact list,
* a new contact with that ID is created, and added to the metacontact @p parent.
*
* @param contactId the @ref Contact::contactId of the contact to create
* @param parent the parent metacontact (must not be 0)
* @param mode the mode used to add the contact. See addContact(const TQString&,const TQString&,Group*,AddMode) for details.
*
* @return @c true if creation of the contact succeeded or the contact was already in the list,
* @c false otherwise.
*/
- bool addContact( const TQString &contactId, MetaContact *parent, AddMode mode = DontChangeKABC );
+ bool addContact( const TQString &contactId, MetaContact *tqparent, AddMode mode = DontChangeKABC );
/**
* @brief Indicate whether the account is connected at all.
@@ -300,7 +301,7 @@ public:
/**
* @brief Indicate whether the account is away.
*
- * This is a convenience method that queries @ref Contact::onlineStatus() on @ref myself().
+ * This is a convenience method that queries @ref Contact::onlinetqStatus() on @ref myself().
* This function is safe to call if @ref setMyself() has not been called yet.
*/
bool isAway() const;
@@ -352,7 +353,7 @@ protected:
* contactId should be the accountID. The online status of the myself contact represents
* the account's status.
*
* The myself should have the @ref ContactList::myself() as parent metacontact
*
*/
void setMyself( Contact *myself );
@@ -363,16 +364,16 @@ protected:
* You shouldn't ever call this method yourself. To add contacts, use @ref addContact().
*
* This method is called by @ref addContact(). In this method, you should create the
* new custom @ref Contact, using @p parentContact as the parent.
*
* If the metacontact is not temporary and the protocol supports it, you can add the
* contact to the server.
*
* @param contactId the ID of the contact to create
* @param parentContact the metacontact to add this contact to
* @return @c true if creating the contact succeeded, @c false on failure.
*/
- virtual bool createContact( const TQString &contactId, MetaContact *parentContact ) =0;
+ virtual bool createContact( const TQString &contactId, MetaContact *tqparentContact ) =0;
/**
@@ -408,7 +409,7 @@ protected slots:
*
* @param status the status to set all contacts of this account except @ref myself() to.
*/
- void setAllContactsStatus( const Kopete::OnlineStatus &status );
+ void setAllContactstqStatus( const Kopete::OnlineStatus &status );
signals:
/**
@@ -449,10 +450,10 @@ public slots:
/**
* @brief Go online for this service.
*
* @param initialStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/
- virtual void connect( const Kopete::OnlineStatus& initialStatus = OnlineStatus() ) = 0;
+ virtual void connect( const Kopete::OnlineStatus& initialtqStatus = OnlineStatus() ) = 0;
/**
* @brief Go offline for this service.
@@ -470,7 +471,7 @@ public slots:
*
* @todo change ; make use of setOnlineStatus
*/
- virtual void setAway( bool away, const TQString &reason = TQString::null );
+ virtual void setAway( bool away, const TQString &reason = TQString() );
/**
* Reimplement this function to set the online status
@@ -478,12 +479,12 @@ public slots:
* @param reason is the away message to set.
* @note If needed, you need to connect. if the offline status is given, you should disconnect
*/
- virtual void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString::null ) = 0;
+ virtual void setOnlineStatus( const Kopete::OnlineStatus& status , const TQString &reason = TQString() ) = 0;
/**
* Display the edit account widget for the account
*/
- void editAccount( TQWidget* parent = 0L );
+ void editAccount( TQWidget* tqparent = 0L );
/**
* Add a user to the blacklist. The default implementation calls
@@ -515,7 +516,7 @@ private slots:
/**
* The @ref myself() contact's online status changed.
*/
- void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newStatus, const Kopete::OnlineStatus &oldStatus );
+ void slotOnlineStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &newtqStatus, const Kopete::OnlineStatus &oldtqStatus );
/**
* The @ref myself() contact's property changed.
@@ -97,12 +98,12 @@ public:
};
/**
- * @param parent the protocol for this account. The account is a child object of the
+ * @param tqparent the protocol for this account. The account is a child object of the
* protocol, so it will be automatically deleted when the protocol is.
* @param accountID the unique ID of this account.
@@ -264,28 +265,28 @@ public:
*
* If a contact for this account with ID @p contactId is not already on the contact list,
- * a new contact with that ID is created, and added to the metacontact @p parent.
+ * a new contact with that ID is created, and added to the metacontact @p tqparent.
*
* @param contactId the @ref Contact::contactId of the contact to create
@@ -264,28 +265,28 @@ public:
*
* @param contactId the @ref Contact::contactId of the contact to create
- * @param parent the parent metacontact (must not be 0)
+ * @param tqparent the tqparent metacontact (must not be 0)
* @param mode the mode used to add the contact. See addContact(const TQString&,const TQString&,Group*,AddMode) for details.
*
@@ -352,7 +353,7 @@ protected:
* the account's status.
*
- * The myself should have the @ref ContactList::myself() as parent metacontact
+ * The myself should have the @ref ContactList::myself() as tqparent metacontact
*
*/
@@ -363,16 +364,16 @@ protected:
*
* This method is called by @ref addContact(). In this method, you should create the
- * new custom @ref Contact, using @p parentContact as the parent.
+ * new custom @ref Contact, using @p tqparentContact as the tqparent.
*
* If the metacontact is not temporary and the protocol supports it, you can add the
@@ -363,16 +364,16 @@ protected:
*
* @param contactId the ID of the contact to create
- * @param parentContact the metacontact to add this contact to
+ * @param tqparentContact the metacontact to add this contact to
* @return @c true if creating the contact succeeded, @c false on failure.
*/
@@ -449,10 +450,10 @@ public slots:
* @brief Go online for this service.
*
- * @param initialStatus is the status to connect with. If it is an invalid status for this
+ * @param initialtqStatus is the status to connect with. If it is an invalid status for this
* account, the default online for the account should be used.
*/